// ****************************************************************************
// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>
// This file is part of knoda -Knorr's Datenbank.
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file COPYING included in the
// packaging of this file.
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// ****************************************************************************

#ifndef KNODAPROGRAM_H
#define KNODAPROGRAM_H
#include "knodaprogrambase.h"
#include <hk_string.h>
#include <kmainwindow.h>
#include <list>
#include <qvariant.h>
#include <qdialog.h>
class hk_drivermanager;
class knodaprogrambase;
/*        typedef class parameters
	{
	 public:
	   hk_string driver;
	  QString database;
	  QString form;
	  bool runtime;
//	  bool internal;
	  bool classic_mdi;
	  bool classic;
	} ;*/

class knodaprogram : public KMainWindow
{
    Q_OBJECT

        public:
        knodaprogram( QWidget* parent = 0, const char* name = 0, WFlags fl = 0  ,struct_commandlinefields* p=0);
        ~knodaprogram();
        void connect_clicked(void);

	protected:
	virtual void closeEvent(QCloseEvent*);
    private:
        knodaprogrambase* p_mainwidget;

};
#endif                                            // KNODAPROGRAM_H
